import { JSONSchema7 as JSONSchema } from 'json-schema';
import * as React from 'react';
import { IChangeEvent, FormProps as JsonSchemaFormProps, UiSchema, WidgetProps, Field, Widget } from '@rjsf/core';
import { BoxProps } from '../Box';
import { ButtonProps } from '../Button';
interface FormState {
    value: any;
    schema: JSONSchema;
}
export interface RenditionUiSchema extends UiSchema {
    'ui:warning'?: string;
}
export interface FormWidgetProps extends WidgetProps {
    registry: {
        fields: {
            [name: string]: Field;
        };
        widgets: {
            [name: string]: Widget;
        };
        definitions: {
            [name: string]: any;
        };
        formContext: any;
    };
    type?: string;
    rawErrors: string[];
}
export interface BaseFormProps extends BoxProps, Pick<JsonSchemaFormProps<any>, 'validate' | 'noValidate' | 'liveValidate' | 'disabled'> {
    submitButtonText?: string | JSX.Element;
    hideSubmitButton?: boolean;
    submitButtonProps?: ButtonProps;
    value?: number | string | boolean | {
        [index: string]: any;
    } | any[] | null;
    onFormChange?: (result: IChangeEvent) => void;
    onFormSubmit?: (result: any) => void;
    uiSchema?: RenditionUiSchema;
}
export interface FormProps extends BaseFormProps {
    schema: JSONSchema;
}
export default class FormHOC extends React.Component<FormProps, FormState> {
    private formRef;
    static getDerivedStateFromProps(props: FormProps, state: FormState): {
        schema: JSONSchema;
        value: string | number | boolean | any[] | {
            [index: string]: any;
        } | null | undefined;
    } | {
        value: string | number | boolean | any[] | {
            [index: string]: any;
        } | null | undefined;
        schema?: undefined;
    } | undefined;
    static registerWidget(name: string, value: any): void;
    componentDidUpdate(prevProps: FormProps): void;
    change: (data: IChangeEvent) => void;
    submit: () => void;
    render(): JSX.Element;
}
export {};
