import { __assign, __makeTemplateObject, __rest } from "tslib";
import { faCheckCircle } from '@fortawesome/free-solid-svg-icons/faCheckCircle';
import { faCircle } from '@fortawesome/free-solid-svg-icons/faCircle';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import findIndex from 'lodash/findIndex';
import * as React from 'react';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import Arrow from '../../internal/Arrow';
import { DismissableContainer } from '../../internal/DismissableContainer';
import { Flex } from '../Flex';
import Heading from '../Heading';
import Link from '../Link';
import Txt from '../Txt';
import { Box } from '../Box';
import { px } from '../../utils';
var StepIconWrapper = styled(Flex)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\talign-items: center;\n\tjustify-content: center;\n\tfont-size: ", ";\n"], ["\n\talign-items: center;\n\tjustify-content: center;\n\tfont-size: ", ";\n"])), function (props) { return px(props.theme.fontSizes[5]); });
var StepIconLabel = styled(Txt)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tfont-size: ", ";\n\theight: ", ";\n\twidth: ", ";\n\tdisplay: flex;\n\talign-items: center;\n\tjustify-content: center;\n\tfont-variant-numeric: tabular-nums;\n"], ["\n\tfont-size: ", ";\n\theight: ", ";\n\twidth: ", ";\n\tdisplay: flex;\n\talign-items: center;\n\tjustify-content: center;\n\tfont-variant-numeric: tabular-nums;\n"])), function (props) { return px(props.theme.fontSizes[3]); }, function (props) { return px(props.theme.fontSizes[5]); }, function (props) { return px(props.theme.fontSizes[5]); });
var OutlineCircle = styled(Box)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\tfont-size: ", ";\n\theight: ", ";\n\twidth: ", ";\n\tborder: 1px solid;\n\tborder-radius: 50%;\n"], ["\n\tfont-size: ", ";\n\theight: ", ";\n\twidth: ", ";\n\tborder: 1px solid;\n\tborder-radius: 50%;\n"])), function (props) { return px(props.theme.fontSizes[3]); }, function (props) { return px(props.theme.fontSizes[5]); }, function (props) { return px(props.theme.fontSizes[5]); });
var StepIcon = function (_a) {
    var ordered = _a.ordered, status = _a.status, active = _a.active, index = _a.index;
    if (status === 'none') {
        return null;
    }
    if (status === 'completed' && !active) {
        return (React.createElement(StepIconWrapper, { mr: 2, color: "success.main" },
            React.createElement(FontAwesomeIcon, { icon: faCheckCircle })));
    }
    if (ordered && active) {
        return (React.createElement(StepIconWrapper, { mr: 2, className: 'fa-layers', color: "primary.main" },
            React.createElement(FontAwesomeIcon, { icon: faCircle }),
            React.createElement(StepIconLabel, { className: "fa-layers-text fa-inverse" }, index + 1)));
    }
    if (ordered && !active) {
        return (React.createElement(StepIconWrapper, { mr: 2, className: 'fa-layers', color: "tertiary.semilight" },
            React.createElement(OutlineCircle, null),
            React.createElement(StepIconLabel, { className: "fa-layers-text" }, index + 1)));
    }
    return (React.createElement(StepIconWrapper, { mr: 2, color: "tertiary.semilight" },
        React.createElement(FontAwesomeIcon, { icon: faCheckCircle })));
};
var StepBase = function (_a) {
    var ordered = _a.ordered, active = _a.active, index = _a.index, status = _a.status, children = _a.children, onClick = _a.onClick;
    if (typeof children !== 'string') {
        throw new Error('The child of a Step has to be a string.');
    }
    return (React.createElement(Flex, { flexDirection: "row", justifyContent: "center", alignItems: "center", fontSize: 2 },
        React.createElement(StepIcon, { ordered: Boolean(ordered), status: status, active: Boolean(active), index: index }),
        onClick ? (React.createElement(Link, { onClick: onClick }, children)) : (React.createElement(Txt, { bold: active, color: active ? undefined : 'tertiary.light' }, children))));
};
export var Step = StepBase;
var FramelessSteps = function (_a) {
    var ordered = _a.ordered, activeStepIndex = _a.activeStepIndex, children = _a.children, otherProps = __rest(_a, ["ordered", "activeStepIndex", "children"]);
    return (React.createElement(Flex, __assign({ mx: "auto", flexDirection: "row", alignItems: "center", flexWrap: "wrap" }, otherProps), React.Children.map(children, function (step, index) {
        if (step.type !== Step) {
            throw new Error('You can only use Step components as children of Steps.');
        }
        var firstPendingStepIndex = findIndex(children, {
            props: { status: 'pending' },
        });
        var enableNextStep = !ordered ||
            firstPendingStepIndex === -1 ||
            firstPendingStepIndex > index;
        var allPrevStepsComplete = firstPendingStepIndex === -1 || firstPendingStepIndex >= index;
        var onClick = !ordered ||
            index < activeStepIndex ||
            (index !== activeStepIndex && allPrevStepsComplete)
            ? step.props.onClick
            : undefined;
        return (React.createElement(Flex, { flexDirection: "row", alignItems: "center" },
            React.cloneElement(step, {
                ordered: ordered,
                index: index,
                onClick: onClick,
                active: activeStepIndex === index,
            }),
            index < children.length - 1 && (React.createElement(Flex, { justifyContent: "center", alignItems: "center", mx: 3 },
                React.createElement(Arrow, { disabled: !enableNextStep })))));
    })));
};
var Steps = React.forwardRef(function (_a, ref) {
    var theme = _a.theme, className = _a.className, children = _a.children, ordered = _a.ordered, bordered = _a.bordered, activeStepIndex = _a.activeStepIndex, titleText = _a.titleText, titleIcon = _a.titleIcon, onClose = _a.onClose;
    if (ordered) {
        if (typeof activeStepIndex !== 'number') {
            throw new Error('You must specify the activeStepIndex for ordered Steps');
        }
        else {
            var stepCount = React.Children.count(children);
            if (activeStepIndex < 0 || activeStepIndex >= stepCount) {
                throw new Error('activeStepIndex is out of range');
            }
        }
    }
    return (React.createElement(DismissableContainer, { className: className, flexDirection: "row", justifyContent: "space-between", flexWrap: "wrap", alignItems: "center", onDismiss: onClose, baselineHeight: theme.fontSizes[3] * theme.lineHeight, bordered: bordered, ref: ref },
        (titleText || titleIcon) && (React.createElement(Flex, { minHeight: theme.fontSizes[5], justifyContent: "center", alignItems: "center", ml: 2, mr: 4 },
            titleIcon && (React.createElement(Txt, { fontSize: 2, mr: 2, color: "tertiary.semilight" }, titleIcon)),
            titleText && (React.createElement(Heading.h6, { color: "tertiary.main" }, titleText)))),
        React.createElement(FramelessSteps, { ordered: Boolean(ordered), activeStepIndex: activeStepIndex }, children)));
});
Steps.defaultProps = {
    bordered: true,
    ordered: false,
};
export default asRendition(Steps);
var templateObject_1, templateObject_2, templateObject_3;
