import { __extends, __makeTemplateObject } from "tslib";
import cloneDeep from 'lodash/cloneDeep';
import * as React from 'react';
import styled from 'styled-components';
import { Terminal as Xterm } from 'xterm';
import { FitAddon } from 'xterm-addon-fit';
import theme from '../../theme';
import defaultXtermStyle from './XTermDefaultStyle';
import { Flex } from '../Flex';
import { ResizeObserver } from 'resize-observer';
var TtyContainer = styled(Flex)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tposition: relative;\n\t", "\n\n\t.xterm-viewport::-webkit-scrollbar-track {\n\t\tbackground-color: transparent;\n\t\tborder-bottom-right-radius: 0;\n\t}\n\n\t.xterm-viewport::-webkit-scrollbar {\n\t\twidth: 10px;\n\t\tbackground-color: transparent;\n\t\tborder-radius: 0;\n\t}\n\n\t.xterm-viewport::-webkit-scrollbar-thumb {\n\t\tbackground-color: #e9e9e9;\n\t}\n"], ["\n\tposition: relative;\n\t", "\n\n\t.xterm-viewport::-webkit-scrollbar-track {\n\t\tbackground-color: transparent;\n\t\tborder-bottom-right-radius: 0;\n\t}\n\n\t.xterm-viewport::-webkit-scrollbar {\n\t\twidth: 10px;\n\t\tbackground-color: transparent;\n\t\tborder-radius: 0;\n\t}\n\n\t.xterm-viewport::-webkit-scrollbar-thumb {\n\t\tbackground-color: #e9e9e9;\n\t}\n"])), defaultXtermStyle);
var TtyInner = styled(Flex)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tposition: absolute;\n\ttop: 0;\n\tleft: 0;\n\tright: 0;\n\tbottom: 0;\n"], ["\n\tposition: absolute;\n\ttop: 0;\n\tleft: 0;\n\tright: 0;\n\tbottom: 0;\n"])));
var Terminal = (function (_super) {
    __extends(Terminal, _super);
    function Terminal(props) {
        var _this = _super.call(this, props) || this;
        _this.termConfig = Object.assign({}, props.config, {
            cursorBlink: false,
            fontFamily: props.theme ? props.theme.monospace : theme.monospace,
            lineHeight: 1.4,
            theme: {
                background: '#343434',
                cursor: props.nonInteractive ? '#343434' : undefined,
            },
        });
        if (_this.props.ttyInstance) {
            _this.tty = _this.props.ttyInstance;
        }
        else {
            _this.tty = Object.assign(new Xterm(cloneDeep(_this.termConfig)), {
                fitAddon: new FitAddon(),
            });
            _this.tty.loadAddon(_this.tty.fitAddon);
        }
        return _this;
    }
    Terminal.prototype.componentDidMount = function () {
        var _this = this;
        setTimeout(function () {
            _this.open();
            if (_this.props.nonInteractive && document.execCommand) {
                _this.tty.attachCustomKeyEventHandler(function (e) {
                    if (e.ctrlKey && e.keyCode === 67) {
                        document.execCommand('copy');
                        return false;
                    }
                    return true;
                });
            }
            _this.resize();
            if (typeof ResizeObserver === 'function') {
                var resizeObserver = new ResizeObserver(function () {
                    _this.resize();
                });
                resizeObserver.observe(_this.mountElement);
            }
        });
    };
    Terminal.prototype.componentWillUnmount = function () {
        if (!this.props.persistent) {
            this.destroy();
        }
    };
    Terminal.prototype.destroy = function () {
        this.tty.dispose();
    };
    Terminal.prototype.open = function () {
        this.tty.open(this.mountElement);
        this.tty.focus();
    };
    Terminal.prototype.resize = function () {
        var mountElementHasHeight = this.mountElement &&
            parseInt(window.getComputedStyle(this.mountElement).getPropertyValue('height'), 10);
        if (!!mountElementHasHeight) {
            try {
                this.tty.fitAddon.fit();
            }
            catch (err) {
                console.log(err);
            }
        }
    };
    Terminal.prototype.clear = function () {
        this.tty.clear();
    };
    Terminal.prototype.writeln = function (line) {
        this.tty.writeln(line);
    };
    Terminal.prototype.write = function (text) {
        this.tty.write(text);
    };
    Terminal.prototype.render = function () {
        var _this = this;
        return (React.createElement(TtyContainer, { flex: "1", height: "100%", color: this.props.color },
            React.createElement(TtyInner, { flex: "1", flexDirection: "column", ref: function (el) { return (_this.mountElement = el); } })));
    };
    return Terminal;
}(React.Component));
export default Terminal;
var templateObject_1, templateObject_2;
