import { __assign, __makeTemplateObject } from "tslib";
import * as React from 'react';
import * as monacoEditor from 'monaco-editor/esm/vs/editor/editor.api';
import MonacoEditor from 'react-monaco-editor';
import get from 'lodash/get';
import cloneDeep from 'lodash/cloneDeep';
import findIndex from 'lodash/findIndex';
import styled from 'styled-components';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faExclamationCircle } from '@fortawesome/free-solid-svg-icons/faExclamationCircle';
import { faCheckCircle } from '@fortawesome/free-solid-svg-icons/faCheckCircle';
import { Flex } from '../../../components/Flex';
import { Box } from '../../../components/Box';
import Heading from '../../../components/Heading';
var EditorWrapper = styled(Flex)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tborder: 1px solid\n\t\t", ";\n"], ["\n\tborder: 1px solid\n\t\t",
    ";\n"])), function (props) {
    return props.isValid
        ? props.theme.colors.quartenary.main
        : props.theme.colors.danger.main;
});
var ValidationBox = styled(Box)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tcolor: ", ";\n"], ["\n\tcolor: ",
    ";\n"])), function (props) {
    return props.hasError
        ? props.theme.colors.danger.main
        : props.theme.colors.success.main;
});
var defaultOptions = {
    minimap: {
        enabled: false,
    },
    lineNumbers: 'off',
    tabSize: 2,
    detectIndentation: false,
    selectOnLineNumbers: true,
};
var monacoEditorSchemas = cloneDeep(get(monacoEditor, ['languages', 'json', 'jsonDefaults', 'diagnosticsOptions', 'schemas'], []));
var getModel = function (fileUri, valueStr) {
    var model = monacoEditor.editor.getModel(fileUri) ||
        monacoEditor.editor.createModel(valueStr, 'json', fileUri);
    model.updateOptions({ tabSize: 2 });
    return model;
};
var JsonEditor = function (_a) {
    var title = _a.title, value = _a.value, onChange = _a.onChange, schema = _a.schema, isValid = _a.isValid;
    var fileName = "file:///" + title + ".json";
    var fileUri = monacoEditor.Uri.parse(fileName);
    var _b = React.useState(getModel(fileUri, value)), model = _b[0], setModel = _b[1];
    React.useEffect(function () {
        setModel(getModel(fileUri, value));
    }, [title, value]);
    React.useEffect(function () {
        if (!schema) {
            return;
        }
        var thisSchema = {
            uri: schema['$schema'] || fileUri.toString(),
            fileMatch: [fileUri.toString()],
            schema: schema,
        };
        var existingSchemaIndex = findIndex(monacoEditorSchemas, {
            uri: thisSchema.uri,
        });
        if (existingSchemaIndex !== -1) {
            monacoEditorSchemas.splice(existingSchemaIndex, 1, thisSchema);
        }
        else {
            monacoEditorSchemas.push(thisSchema);
        }
        monacoEditor.languages.json.jsonDefaults.setDiagnosticsOptions({
            validate: true,
            schemas: monacoEditorSchemas,
        });
    }, [schema]);
    return (React.createElement(Flex, { flex: "1 1 0", flexDirection: "column" },
        React.createElement(Flex, { justifyContent: "space-between", alignItems: "center" },
            title && React.createElement(Heading.h5, null, title),
            React.createElement(ValidationBox, { hasError: !isValid, tooltip: "JSON is " + (isValid ? 'valid' : 'invalid') },
                React.createElement(FontAwesomeIcon, { icon: isValid ? faCheckCircle : faExclamationCircle }))),
        React.createElement(EditorWrapper, { flex: 1, mb: 2, isValid: isValid },
            React.createElement(MonacoEditor, { language: "json", theme: "vs", height: "100%", options: __assign(__assign({}, defaultOptions), { model: model }), value: value, onChange: onChange }))));
};
export default JsonEditor;
var templateObject_1, templateObject_2;
