import { __assign } from "tslib";
import first from 'lodash/first';
import forEach from 'lodash/forEach';
import get from 'lodash/get';
import without from 'lodash/without';
import uniq from 'lodash/uniq';
import castArray from 'lodash/castArray';
import keys from 'lodash/keys';
import widgets from '../widgets';
import { getWidget, getType } from '../index';
import { WidgetWrapperUiOptions, getObjectPropertyNames } from '../widgets';
import { transformUiSchema } from '../widgets/widget-util';
var getBaseMetaSchema = function () { return ({
    title: 'JsonSchemaRenderer UI Schema',
    type: ['object', 'null'],
    properties: {
        'ui:title': {
            type: ['string', 'null'],
        },
        'ui:description': {
            type: ['string', 'null'],
        },
        'ui:value': {
            type: ['string', 'object', 'null'],
        },
        'ui:options': {
            type: 'object',
        },
    },
}); };
var generateArrayMetaSchema = function (metaSchema, _a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema, extraContext = _a.extraContext;
    var arrayValue = value;
    var itemsUiSchema = get(uiSchema, 'items', {});
    var itemsSchema = get(schema, 'items', {});
    metaSchema.properties.items = generateUiSchemaMetaSchema({
        value: first(arrayValue),
        schema: typeof itemsSchema === 'boolean' ? {} : itemsSchema,
        uiSchema: itemsUiSchema,
        extraContext: extraContext,
    });
};
var generateObjectMetaSchema = function (metaSchema, _a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema, extraContext = _a.extraContext;
    metaSchema.properties['ui:order'] = {
        type: ['array'],
        items: {
            type: 'string',
            enum: keys(schema.properties).concat(['*']),
        },
    };
    var propertyNames = getObjectPropertyNames({
        value: value || '',
        schema: schema,
        uiSchema: uiSchema || {},
    });
    forEach(propertyNames, function (propertyName) {
        var subSchema = get(schema, ['properties', propertyName], {});
        var subUiSchema = get(uiSchema, propertyName, {});
        metaSchema.properties[propertyName] = generateUiSchemaMetaSchema({
            value: get(value, propertyName),
            schema: typeof subSchema === 'boolean' ? {} : subSchema,
            uiSchema: subUiSchema,
            extraContext: extraContext,
        });
    });
};
var setWidgetOptions = function (metaSchema, type) {
    var widgetKeys = [];
    castArray(type).reduce(function (acc, t) {
        acc.push.apply(acc, keys(widgets[t]));
        return acc;
    }, widgetKeys);
    metaSchema.properties['ui:widget'] = {
        oneof: [
            {
                type: 'string',
                enum: without(uniq(widgetKeys), 'default'),
            },
            {
                type: 'object',
            },
        ],
    };
};
var setUiOptions = function (metaSchema, _a) {
    var value = _a.value, uiSchema = _a.uiSchema;
    var widget = getWidget(value, get(uiSchema, 'ui:widget'));
    metaSchema.properties['ui:options'] = {
        type: 'object',
        properties: __assign(__assign({}, WidgetWrapperUiOptions), widget.uiOptions),
    };
};
export var generateUiSchemaMetaSchema = function (_a) {
    var unprocessedValue = _a.value, uiSchema = _a.uiSchema, schema = _a.schema, extraContext = _a.extraContext;
    var metaSchema = getBaseMetaSchema();
    var processedUiSchema = transformUiSchema({
        value: unprocessedValue,
        uiSchema: uiSchema,
        extraContext: extraContext,
    });
    var input = {
        value: get(processedUiSchema, 'ui:value', unprocessedValue),
        schema: schema,
        uiSchema: processedUiSchema,
        extraContext: extraContext,
    };
    var type = getType(input.value);
    if (type === 'object') {
        generateObjectMetaSchema(metaSchema, input);
    }
    else if (type === 'array') {
        generateArrayMetaSchema(metaSchema, input);
    }
    if (type) {
        setWidgetOptions(metaSchema, type);
    }
    setUiOptions(metaSchema, input);
    return metaSchema;
};
