export declare const CONTEXT_FUNCTIONS: {
    fns: {
        prependHello: (input: string) => string;
    };
};
declare const jsonDataExamples: {
    'A string': {
        value: string;
        schema: {
            type: string;
            title: string;
            description: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                bold: boolean;
                italic: boolean;
                monospace: boolean;
                caps: boolean;
                align: string;
                whitespace: string;
            };
        };
    };
    'A number': {
        value: number;
        schema: {
            type: string;
            title: string;
            description: string;
        };
        uiSchema: {};
    };
    'An integer': {
        value: number;
        schema: {
            type: string;
            title: string;
            description: string;
        };
        uiSchema: {};
    };
    'A boolean': {
        value: boolean;
        schema: {
            type: string;
            title: string;
            description: string;
        };
        uiSchema: {
            'ui:options': {
                label: string;
                reverse: boolean;
                toggle: boolean;
            };
        };
    };
    'A null object': {
        value: null;
        schema: {
            type: string;
            title: string;
            description: string;
        };
        uiSchema: {
            'ui:widget': string;
        };
    };
    'An array of strings field': {
        value: string[];
        schema: {
            type: string;
            items: {
                type: string;
            };
        };
        uiSchema: {
            items: {
                'ui:widget': string;
            };
        };
    };
    'An invalid value': {
        value: {
            eh: string;
        };
        schema: {
            type: string;
            title: string;
            description: string;
        };
        uiSchema: {};
    };
    'A hidden field': {
        value: {
            hidden: string;
            shown: string;
        };
        schema: {
            type: string;
            properties: {
                hidden: {
                    type: string;
                };
                shown: {
                    type: string;
                };
            };
        };
        uiSchema: {
            hidden: null;
        };
    };
    'A hidden title': {
        value: string;
        schema: {
            type: string;
            title: string;
        };
        uiSchema: {
            'ui:title': null;
        };
    };
    'An object with various properties': {
        value: {
            aString: string;
            aNumber: number;
            anInteger: number;
            aBoolean: boolean;
            aNull: null;
        };
        schema: {
            type: string;
            title: string;
            description: string;
            properties: {
                aString: {
                    type: string;
                    title: string;
                };
                aNumber: {
                    type: string;
                    title: string;
                };
                anInteger: {
                    type: string;
                    title: string;
                };
                aBoolean: {
                    type: string;
                    title: string;
                };
                aNull: {
                    type: string;
                    title: string;
                };
            };
        };
        uiSchema: {
            aString: {
                'ui:widget': string;
            };
            aNumber: {
                'ui:widget': string;
            };
            anInteger: {
                'ui:widget': string;
            };
            aBoolean: {
                'ui:widget': string;
            };
            aNull: {
                'ui:widget': string;
            };
        };
    };
    'Re-ordered fields': {
        value: {
            fieldA: string;
            fieldB: string;
            fieldC: string;
        };
        schema: {
            type: string;
            properties: {
                fieldA: {
                    type: string;
                };
                fieldB: {
                    type: string;
                };
                fieldC: {
                    type: string;
                };
            };
        };
        uiSchema: {
            'ui:order': string[];
        };
    };
    'A truncated string': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                truncate: boolean;
            };
        };
    };
    'A truncated array of strings field': {
        value: string[];
        schema: {
            type: string;
            items: {
                type: string;
            };
        };
        uiSchema: {
            'ui:options': {
                truncate: number;
            };
        };
    };
    'A string-interpolated value': {
        value: number;
        schema: {
            type: string;
            title: string;
        };
        uiSchema: {
            'ui:value': string;
        };
    };
    'An evaluated value': {
        value: number;
        schema: {
            type: string;
            title: string;
        };
        uiSchema: {
            'ui:title': string;
            'ui:widget': string;
            'ui:value': {
                $eval: string;
            };
        };
    };
    'Using context functions': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:value': {
                $eval: string;
            };
        };
    };
    'A materialized field': {
        value: {
            firstName: string;
            lastName: string;
        };
        schema: {
            type: string;
            properties: {
                firstName: {
                    type: string;
                };
                lastName: {
                    type: string;
                };
            };
        };
        uiSchema: {
            firstName: null;
            lastName: null;
            'ui:field:fullName': {
                'ui:title': string;
                'ui:widget': string;
                'ui:value': string;
            };
        };
    };
    'A badge widget': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                shade: number;
            };
        };
    };
    'A button widget': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                href: string;
                target: string;
                disabled: boolean;
                primary: boolean;
                secondary: boolean;
                tertiary: boolean;
                quarternary: boolean;
                danger: boolean;
                warning: boolean;
                success: boolean;
                info: boolean;
                light: boolean;
                outline: boolean;
                plain: boolean;
                underline: boolean;
            };
        };
    };
    'A button group widget': {
        value: string[];
        schema: {
            type: string;
            items: {
                type: string;
            };
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                disabled: boolean;
                primary: boolean;
                secondary: boolean;
                tertiary: boolean;
                quarternary: boolean;
                danger: boolean;
                warning: boolean;
                success: boolean;
                info: boolean;
                light: boolean;
                outline: boolean;
                plain: boolean;
                underline: boolean;
            };
        };
    };
    'A drop-down button widget': {
        value: string[];
        schema: {
            type: string;
            items: {
                type: string;
            };
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                label: string;
                disabled: boolean;
                primary: boolean;
                secondary: boolean;
                tertiary: boolean;
                quarternary: boolean;
                danger: boolean;
                warning: boolean;
                success: boolean;
                info: boolean;
                light: boolean;
                outline: boolean;
                plain: boolean;
                underline: boolean;
            };
        };
    };
    'A Link widget': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:value': string;
            'ui:options': {
                blank: boolean;
                href: string;
            };
        };
    };
    'An Img widget': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                width: number;
                alt: string;
            };
        };
    };
    'A Tag widget': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                name: string;
            };
        };
    };
    'A HighlightedName widget': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                bg: string;
                color: string;
            };
        };
    };
    'A Heading widget': {
        value: string;
        schema: {
            type: string;
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                size: number;
            };
        };
    };
    'A Markdown widget': {
        value: string;
        schema: {
            type: string;
            format: string;
        };
        uiSchema: {
            'ui:widget': string;
        };
    };
    'A List widget': {
        value: string[];
        schema: {
            type: string;
            items: {
                type: string;
            };
        };
        uiSchema: {
            'ui:widget': string;
            'ui:options': {
                ordered: boolean;
            };
            items: {
                'ui:widget': string;
                'ui:options': {
                    href: string;
                };
            };
        };
    };
};
export default jsonDataExamples;
