import { __assign, __rest, __spreadArrays } from "tslib";
import * as React from 'react';
import forEach from 'lodash/forEach';
import keys from 'lodash/keys';
import pick from 'lodash/pick';
import get from 'lodash/get';
import isArray from 'lodash/isArray';
import ajv from 'ajv';
import asRendition from '../../asRendition';
import { Flex } from '../../components/Flex';
import Alert from '../../components/Alert';
import ErrorBoundary from '../../internal/ErrorBoundary';
import widgets, { WidgetWrapperUiOptions, WidgetMeta } from './widgets';
import { transformUiSchema } from './widgets/widget-util';
export var getValue = function (value, uiSchema) {
    return get(uiSchema, 'ui:value', value);
};
var widgetWrapperUiOptionKeys = keys(WidgetWrapperUiOptions);
export var getType = function (value) {
    if (value === undefined) {
        return 'default';
    }
    if (value === null) {
        return 'null';
    }
    return isArray(value) ? 'array' : typeof value;
};
export var getWidget = function (value, uiSchemaWidget) {
    if (uiSchemaWidget && typeof uiSchemaWidget !== 'string') {
        return uiSchemaWidget;
    }
    var typeWidgets = get(widgets, getType(value), widgets.default);
    return get(typeWidgets, uiSchemaWidget || 'default', typeWidgets.default);
};
var buildValidation = function (schema, extraFormats) {
    var validator = new ajv();
    forEach(extraFormats, function (_a) {
        var name = _a.name, format = _a.format;
        validator.addFormat(name, format);
    });
    return {
        validator: validator,
        validate: validator.compile(schema || {}),
    };
};
export var JsonSchemaRenderer = function (_a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema, valueKey = _a.valueKey, extraFormats = _a.extraFormats, extraContext = _a.extraContext, validate = _a.validate, nested = _a.nested, props = __rest(_a, ["value", "schema", "uiSchema", "valueKey", "extraFormats", "extraContext", "validate", "nested"]);
    var _b = React.useState(validate && !nested ? buildValidation(schema, extraFormats) : null), validation = _b[0], setValidation = _b[1];
    var _c = React.useState(null), validationErrors = _c[0], setValidationErrors = _c[1];
    React.useEffect(function () {
        if (!validate || nested) {
            setValidationErrors(null);
            return;
        }
        setValidation(buildValidation(schema, extraFormats));
    }, [validate, nested, extraFormats, schema]);
    React.useEffect(function () {
        if (!validate || nested) {
            return;
        }
        var v = validation;
        if (!v) {
            v = buildValidation(schema, extraFormats);
            setValidation(v);
        }
        v.validate(value);
        setValidationErrors(v.validate.errors);
    }, [validate, nested, validation, value]);
    if (uiSchema === null) {
        return null;
    }
    var processedUiSchema = transformUiSchema({
        value: value,
        uiSchema: uiSchema,
        extraContext: extraContext,
    });
    var processedValue = getValue(value, processedUiSchema);
    if (processedValue === undefined || processedValue === null) {
        return null;
    }
    var wrapperProps = pick.apply(void 0, __spreadArrays([get(processedUiSchema, 'ui:options', {})], widgetWrapperUiOptionKeys));
    var Widget = getWidget(processedValue, processedUiSchema['ui:widget']);
    return (React.createElement(Flex, __assign({ minWidth: 0, minHeight: 0, alignItems: "flex-start", mb: 1, flexDirection: "column" }, props, wrapperProps),
        validationErrors && (React.createElement(Alert, { my: 2, plaintext: true, danger: true, tooltip: validation === null || validation === void 0 ? void 0 : validation.validator.errorsText(validationErrors) }, "Invalid data/schema")),
        React.createElement(WidgetMeta, { schema: schema, uiSchema: processedUiSchema, valueKey: valueKey }),
        React.createElement(Widget, { extraContext: extraContext, value: processedValue, schema: schema, uiSchema: processedUiSchema })));
};
export var RenditionJsonSchemaRenderer = asRendition(JsonSchemaRenderer);
export default function (props) {
    return (React.createElement(ErrorBoundary, null,
        React.createElement(RenditionJsonSchemaRenderer, __assign({}, props))));
}
