import { __assign, __spreadArrays } from "tslib";
import * as React from 'react';
import jsone from 'json-e';
import merge from 'lodash/merge';
import pickBy from 'lodash/pickBy';
import difference from 'lodash/difference';
import isArray from 'lodash/isArray';
import keys from 'lodash/keys';
import concat from 'lodash/concat';
import get from 'lodash/get';
import pick from 'lodash/pick';
export function withOptionProps(uiOptions) {
    return function (Component) {
        var wrapped = function (props) {
            var extraProps = pick.apply(void 0, __spreadArrays([get(props.uiSchema, 'ui:options', {})], keys(uiOptions)));
            return React.createElement(Component, __assign({}, props, extraProps));
        };
        wrapped.uiOptions = Component.uiOptions;
        wrapped.supportedTypes = Component.supportedTypes;
        return wrapped;
    };
}
export var transformUiSchema = function (_a) {
    var value = _a.value, uiSchema = _a.uiSchema, extraContext = _a.extraContext;
    var context = __assign({ source: value }, extraContext);
    if (typeof value === 'object') {
        var trimmedUiSchema = pickBy(uiSchema || {}, function (_, k) {
            return k.startsWith('ui:');
        });
        var processedUiSchema = jsone(trimmedUiSchema, context);
        return merge({}, uiSchema, processedUiSchema);
    }
    return jsone(uiSchema || {}, context);
};
export var getArrayItems = function (_a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema, extraContext = _a.extraContext;
    if (!isArray(value)) {
        throw new Error("Value must be an array (not '" + typeof value + "')");
    }
    var maxItems = get(uiSchema, ['ui:options', 'truncate'], value.length);
    var items = value.slice(0, maxItems).map(function (item) {
        var itemSchema = get(schema, 'items', {});
        var itemUiSchema = get(uiSchema, 'items', {});
        var processedUiSchema = transformUiSchema({
            value: item,
            uiSchema: itemUiSchema,
            extraContext: extraContext,
        });
        return {
            value: item,
            schema: itemSchema,
            uiSchema: processedUiSchema,
            extraContext: extraContext,
        };
    });
    if (maxItems < value.length) {
        items.push({
            value: "+ " + (value.length - maxItems) + " more",
            schema: {
                type: 'string',
            },
            uiSchema: {},
            extraContext: extraContext,
        });
    }
    return items;
};
var getMaterializedPropertyNames = function (uiSchema) {
    return keys(uiSchema).filter(function (uiSchemaKey) {
        return uiSchemaKey.startsWith('ui:field:');
    });
};
export function getObjectPropertyNames(_a) {
    var value = _a.value, schema = _a.schema, uiSchema = _a.uiSchema;
    if (typeof value !== 'object') {
        throw new Error("Cannot get object property names from a value of type '" + typeof value + "'");
    }
    var uiSchemaPropertyNames = getMaterializedPropertyNames(uiSchema);
    var schemaPropertyNames = get(uiSchema, ['ui:order'], keys(get(schema, 'properties'))) || [];
    var nonSchemaPropertyNames = difference(keys(value) || [], schemaPropertyNames);
    return concat(uiSchemaPropertyNames, schemaPropertyNames, nonSchemaPropertyNames);
}
